@@ -1577,6 +1577,12 @@ class TestAltGuessings(TestCase):
         alts = map.get_alts_list()
         self.assertEqual([('cat', [['cat', 'cat_1']]), ('dog', [['dog', 'dog_1']])], alts)
 
+    def test_no_crackles(self):
+        # If there is no foo then foo1 is not an alternative texture
+        map = GridMap((0, 0, 32, 32), (16, 16), ['cat1', 'cat2', 'cat3', 'dog1'])
+        alts = map.get_alts_list()
+        self.assertEqual([], alts)
+
     def test_simple_case_sans_underscore(self):
         map = GridMap((0, 0, 32, 32), (16, 16), ['cat', 'dog', 'cat1', 'dog1'])
         alts = map.get_alts_list()
