@@ -650,12 +650,16 @@ class MapBase(object):
                 groups.setdefault(group_name, {}).setdefault(cell_name, []).append(name)
 
         # Second pass: Add cells for which alt versions exist.
+        # Discard any which do not have an non-alt cell as false positives.
+        ngroups = {}
         for cell_name in self.names:
             m = side_re.search(cell_name)
             group_name = cell_name[:m.start(0)] if m else cell_name
             names = groups.get(group_name, {}).get(cell_name)
             if names:
-                names.insert(0, cell_name)
+                ngroups.setdefault(group_name, {})[cell_name] = [cell_name] + names
+        groups = ngroups
+
         return sorted((cn, sorted(ns.values())) for (cn, ns) in groups.items())
 
 
